@@ -21,7 +21,7 @@
 #' @param family_filter (character) A division (aka phylum) name to filter
 #' data after retrieved from NCBI. Optional. See `Filtering` below.
 #' @param rank_filter (character) A taxonomic rank name to filter data after
-#' retrieved from NCBI. See [rank_ref()] for possible options.
+#' retrieved from NCBI. See [rank_ref] for possible options.
 #' Though note that some data sources use atypical ranks, so inspect the data
 #' itself for options. Optional. See `Filtering` below.
 #' @param check logical; Check if ID matches any existing on the DB, only 
@@ -36,6 +36,13 @@
 #' subset that is closer to the target you want.  For these two parameters,
 #' you can use regex strings since we use [grep()] internally to match.
 #' Filtering narrows down to the set that matches your query, and removes the rest.
+#' 
+#' @section Rate-limits:
+#' As of February 2019, KEW was limiting to 5 requests per second. Note that
+#' they may change that number in the future.
+#' 
+#' If you get errors that contain `429` you are hitting the rate limit, and you
+#' can get around it by doing requests with `Sys.sleep` in between requests.
 #'
 #' @family taxonomic-ids
 #' @seealso [classification()]
@@ -97,8 +104,11 @@ get_pow <- function(sci_com, accepted = FALSE, ask = TRUE, messages = TRUE,
   assert(family_filter, "character")
   assert(rank_filter, "character")
   assert_rows(rows)
-  pchk(x, "sci_com")
-
+  if (!is.null(x)) {
+    lifecycle::deprecate_warn(when = "v0.9.97", what = "get_pow(x)", with = "get_pow(sci_com)")
+    sci_com <- x
+  }
+  
   if (inherits(sci_com, "character")) {
     tstate <- taxon_state$new(class = "pow", names = sci_com)
     items <- sci_com
@@ -126,6 +136,10 @@ get_pow <- function(sci_com, accepted = FALSE, ask = TRUE, messages = TRUE,
     } else {
       pow_df <- pow_df[, c("name","rank","accepted","kingdom","family","fqId")]
 
+      if (accepted) {
+        pow_df <- pow_df[pow_df$accepted, ]
+      }
+      
       # should return NA if spec not found
       if (nrow(pow_df) == 0) {
         mssg(messages, "Not found. Consider checking the spelling or alternate classification")
@@ -133,10 +147,6 @@ get_pow <- function(sci_com, accepted = FALSE, ask = TRUE, messages = TRUE,
         att <- 'not found'
       }
 
-      if (accepted) {
-        pow_df <- pow_df[pow_df$accepted, ]
-      }
-
       # take the one pow from data.frame
       if (nrow(pow_df) == 1) {
         pow <- pow_df$fqId
@@ -182,7 +192,7 @@ get_pow <- function(sci_com, accepted = FALSE, ask = TRUE, messages = TRUE,
           if (length(pow) > 1 || NROW(pow_df) > 1) {
             # prompt
             message("\n\n")
-            print(pow_df)
+            message(paste0(utils::capture.output(pow_df), collapse = "\n"))
             message("\nMore than one pow found for taxon '", sci_com[i], "'!\n
           Enter rownumber of taxon (other inputs will return 'NA'):\n") # prompt
             take <- scan(n = 1, quiet = TRUE, what = 'raw')
@@ -268,7 +278,7 @@ as.data.frame.pow <- function(x, ...){
 }
 
 make_pow <- function(x, check=TRUE) {
-  make_generic(x, 'http://powo.science.kew.org/taxon/%s', "pow", check)
+  make_generic(x, 'https://powo.science.kew.org/taxon/%s', "pow", check)
 }
 
 check_pow <- function(x){
@@ -279,7 +289,11 @@ check_pow <- function(x){
 #' @export
 #' @rdname get_pow
 get_pow_ <- function(sci_com, messages = TRUE, rows = NA, x = NULL, ...) {
-  pchk(x, "sci_com")
+  if (!is.null(x)) {
+    lifecycle::deprecate_warn(when = "v0.9.97", what = "get_pow_(x)", with = "get_pow_(sci_com)")
+    sci_com <- x
+  }
+  
   stats::setNames(lapply(sci_com, get_pow_help, messages = messages,
     rows = rows, ...), sci_com)
 }
