@@ -21,13 +21,13 @@
 #' Subtree, Synonym, Text Word. These are not checked, so make sure they are
 #' entered correctly, as is.
 #' @param rank_query (character) A taxonomic rank name to modify the query sent
-#' to NCBI. See [rank_ref()] for possible options. Though note that
+#' to NCBI. See [rank_ref] for possible options. Though note that
 #' some data sources use atypical ranks, so inspect the data itself for
 #' options. Optional. See `Querying` below.
 #' @param division_filter (character) A division (aka phylum) name to filter
 #' data after retrieved from NCBI. Optional. See `Filtering` below.
 #' @param rank_filter (character) A taxonomic rank name to filter data after
-#' retrieved from NCBI. See [rank_ref()] for possible options.
+#' retrieved from NCBI. See [rank_ref] for possible options.
 #' Though note that some data sources use atypical ranks, so inspect the data
 #' itself for options. Optional. See `Filtering` below.
 #' @param key (character) NCBI Entrez API key. optional. See Details.
@@ -37,6 +37,10 @@
 #' @param check logical; Check if ID matches any existing on the DB, only used
 #'   in [as.uid()]
 #' @template getreturn
+#' 
+#' @section Rate limits:
+#' In case you run into errors due to your rate limit being exceeded, see
+#' [taxize_options()], where you can set `ncbi_sleep`.
 #'
 #' @section Querying: The parameter `rank_query` is used in the search sent
 #'   to NCBI, whereas `rank_filter` filters data after it comes back. The
@@ -68,7 +72,7 @@
 #' 
 #' @section HTTP version:
 #' We hard code `http_version = 2L` to use HTTP/1.1 in HTTP requests to
-#' the Entrez API. See `curl::curl_symbols('CURL_HTTP_VERSION')` 
+#' the Entrez API. See `curl::curl_symbols('CURL_HTTP_VERSION')`
 #'
 #' @family taxonomic-ids
 #' @seealso [classification()]
@@ -170,7 +174,11 @@ get_uid <- function(sci_com, ask = TRUE, messages = TRUE, rows = NA,
   assert(rank_filter, "character")
   assert_rows(rows)
   key <- getkey(key, service = "entrez")
-  pchk(sciname, "sci_com")
+  if (!is.null(sciname)) {
+    lifecycle::deprecate_warn(when = "v0.9.97", what = "get_uid(sciname)", with = "get_uid(sci_com)")
+    sci_com <- sciname
+  }
+  
 
   if (inherits(sci_com, "character")) {
     tstate <- taxon_state$new(class = "uid", names = sci_com)
@@ -202,6 +210,7 @@ get_uid <- function(sci_com, ask = TRUE, messages = TRUE, rows = NA,
                                             "esearch",
                                             query = query_args,
                                             ...)
+    if (grepl("error", raw_xml_result)) stop(raw_xml_result, call.=FALSE)
     xml_result <- xml2::read_xml(raw_xml_result)
 
     # NCBI limits requests to three per second
@@ -276,7 +285,7 @@ get_uid <- function(sci_com, ask = TRUE, messages = TRUE, rows = NA,
           message("\n\n")
           message("\nMore than one UID found for taxon '", sci_com[i], "'!\n
             Enter rownumber of taxon (other inputs will return 'NA'):\n")
-          print(df)
+          message(paste0(utils::capture.output(df), collapse = "\n"))
           take <- scan(n = 1, quiet = TRUE, what = 'raw')
 
           if (length(take) == 0) {
@@ -401,7 +410,11 @@ get_uid_ <- function(sci_com, messages = TRUE, rows = NA, key = NULL,
   sciname = NULL, ...) {
   
   key <- getkey(key, "ENTREZ_KEY")
-  pchk(sciname, "sci_com")
+  if (!is.null(sciname)) {
+  lifecycle::deprecate_warn(when = "v0.9.97", what = "get_uid_(sciname)", with = "get_uid_(sci_com)")
+    sci_com <- sciname
+  }
+  
   stats::setNames(lapply(sci_com, get_uid_help, messages = messages,
     rows = rows, key = key, ...), sci_com)
 }
